# SaraikiNLP: The Python NLP Framework for Saraiki Language Research

<div align="center">
<a href="https://github.com/SaraikiNLP/SaraikiNLP"><img src="https://img.shields.io/badge/Github-SaraikiNLP-blue?logo=github"/></a>
<a href="https://huggingface.co/SaraikiNLP"><img src="https://img.shields.io/badge/Hugging%20Face-SaraikiNLP-yellow?logo=huggingface"/></a>
<a href="https://github.com/SaraikiNLP/SaraikiNLP/graphs/contributors"><img src="https://img.shields.io/github/contributors/SaraikiNLP/SaraikiNLP.svg" /></a>
<a href="https://pepy.tech/project/SaraikiNLP"><img src="https://pepy.tech/badge/SaraikiNLP" /></a>
<a href="https://github.com/SaraikiNLP/SaraikiNLP/blob/master/LICENSE"><img src="https://img.shields.io/badge/license-MIT-blue.svg" /></a>
</div>

---

## Table of Contents

1. Introduction
2. Why Saraiki?
   - About the Saraiki Language
   - Why Should One Work on Saraiki NLP?
   - The Goal of SaraikiNLP
3. Intended Audience
4. Features
5. Installation
6. Documentation
7. Resources
8. Contributing
9. License

---

## Introduction

**SaraikiNLP** is the world's first and fundamental **Python framework** for **Saraiki language research**. It comes with **basic NLP functions** to help researchers, students, and anyone interested in Saraiki NLP work.


---

## Why Saraiki?

### About the Saraiki Language

**Saraiki (skr)** is an **Indo-Aryan** language spoken by over 25–30 million people, primarily in Pakistan. It is spoken in **Southern Punjab** in cities like **Multan**, **Bahawalpur**, **Dera Ghazi Khan**, and **Rahim Yar Khan**, and extends into parts of **Sindh**, **Balochistan**, and **Khyber Pakhtunkhwa**. Despite its rich linguistic and cultural heritage, Saraiki remains underrepresented in NLP and research.

### Why Should One Work on Saraiki NLP?

Despite having millions of speakers, Saraiki still lacks digital resources, computational tools, and NLP support. Major challenges include:

- **Limited Text Datasets** – Few machine-readable corpora are available.
- **Minimal NLP Research** – There is less work on tokenization, lemmatization, named entity recognition (NER), or speech recognition.
- **No Official Status** – Unlike Urdu or Punjabi, Saraiki lacks mainstream software support in AI and ML applications.

### The Goal of SaraikiNLP

The **SaraikiNLP project** aims to:

- **Developing Core NLP Tools** – Implement normalization, tokenization, lemmatization, stemming, and NER models.
- **Promote Saraiki Research** – Increase awareness and support for research in this low resource language.

---

## Intended Audience

- **Science/Research:** For researchers and linguists experimenting with Saraiki language data.
- **Developers:** To help build Saraiki applications with less effort.
- **Education:** Providing resources and tools for students interested in Saraiki language research.

---

## Features 

- [X] Normalization
- [X] Preprocessing
- [ ] Conversion (Weekdays, Months, Counting)
- [ ] Tokenization
- [ ] Stemming
- [ ] Lemmatization
- [ ] Saraiki Models
  - [ ] Named Entity Recognition (NER)
  - [ ] Part of Speech Tagger (POS Tagger)
  - [ ] Sentimental Analysis
  - [ ] Text Summarization

---

## Installation

Using **pip**, SaraikiNLP can be easily installed:

```bash
pip install SaraikiNLP
```

---

## Documentation
----------------

| Documentation   |                                                                |
| --------------- | -------------------------------------------------------------- |
| [Normalization]  | Our functions and usage examples for normalization. |
| [Preprocessing]    | Functions SaraikiNLP provides for preprocessing. |
| [Conversion]    | Functions SaraikiNLP provides for conversion of month names, numbers and week days. |
| [Tokenization]    | Functions for tokenization. |
| [Stemming]    | Functions for stemming. |
| [Lemmatization]    | Functions for lemmatization. |
| [Named entity recognition]    | NER using this package. |
| [Part of speech (POS) tagging]    | POS using SaraikiNLP. |
| [Sentimental analysis]    | Analyze sentiment using package's built in functions. |
| [Text summarization]    | Summarize Saraiki text easily. |

[Normalization]: https://github.com/SaraikiNLP/SaraikiNLP/blob/main/Documentation/normalization.md
[Preprocessing]: https://github.com/SaraikiNLP/SaraikiNLP/blob/main/Documentation/preprocessing.md
[Conversion]: https://github.com/SaraikiNLP/SaraikiNLP/blob/main/Documentation/conversion.md
[Tokenization]: https://github.com/SaraikiNLP/SaraikiNLP/blob/main/Documentation/tokenization.md
[Stemming]: https://github.com/SaraikiNLP/SaraikiNLP/blob/main/Documentation/stemming.md
[Lemmatization]: https://github.com/SaraikiNLP/SaraikiNLP/blob/main/Documentation/lemmatization.md
[Named entity recognition]: https://github.com/SaraikiNLP/SaraikiNLP/blob/main/Documentation/ner.md
[Part of speech (POS) tagging]: https://github.com/SaraikiNLP/SaraikiNLP/blob/main/Documentation/pos.md
[Sentimental analysis]: https://github.com/SaraikiNLP/SaraikiNLP/blob/main/Documentation/sentiment.md
[Text summarization]: https://github.com/SaraikiNLP/SaraikiNLP/blob/main/Documentation/summarization.md

---

## Resources

| Resources   |                                                                |
| --------------- | -------------------------------------------------------------- |
| [Saraiki Alphabets]  | Saraiki alphabets |
| [Saraiki Counting]    | Saraiki counting |
| [Saraiki Months]     | Saraiki month names with Urdu and English counterparts |
| [Saraiki Week Days]  | Saraiki day names with counterparts |
| [Current Saraiki Research] | Current research being done on Saraiki language |


[Saraiki Alphabets]: https://github.com/SaraikiNLP/SaraikiNLP/blob/main/Resources/saraiki_alphabets.md
[Saraiki Counting]: https://github.com/SaraikiNLP/SaraikiNLP/blob/main/Resources/saraiki_counting.md
[Saraiki Months]: https://github.com/SaraikiNLP/SaraikiNLP/blob/main/Resources/saraiki_months.md
[Saraiki Week Days]: https://github.com/SaraikiNLP/SaraikiNLP/blob/main/Resources/saraiki_week_days.md
[Current Saraiki Research]: https://github.com/SaraikiNLP/SaraikiNLP/blob/main/Resources/saraiki_research.md

---

## Contributing

We welcome contributions from everyone! If you'd like to help improve **SaraikiNLP**.

Your contributions help make **SaraikiNLP** better for everyone. **Thank you for your interest! :-)**

---

## Copyright and license
------------------------
Code released under the [MIT License](https://github.com/SaraikiNLP/SaraikiNLP/blob/master/LICENSE.md).




